@@ -1,7 +1,7 @@
 from enum import Enum
 
 _defaultValues = {'STRING': "''", 'INTEGER': '0', 'LONG': '0', 'FLOAT': '0', 'DOUBLE': '0', 'BOOLEAN': "''",
-                  'DATE': 'CURRENT_TIMESTAMP()', 'CHAR': "''", 'BYTE': "''", 'MODEL': "''"}
+                  'DATE': 'CURRENT_TIMESTAMP()', 'CHAR': "''", 'BYTE': "''", 'MODEL': "''", 'JSON': "''", 'BLOB': "''"}
 
 
 class DataTypeEnum(Enum):
@@ -15,6 +15,8 @@ class DataTypeEnum(Enum):
     CHAR = "CHAR"
     BYTE = "BYTE"
     MODEL = "MODEL"
+    JSON = "JSON"
+    BLOB = "BLOB"
 
     def __new__(cls, name):
         obj = object.__new__(cls)
