@@ -9,6 +9,7 @@ import requests
 from munch import Munch
 
 from api.exceptions import ServiceInnerException, IllegalArgumentException, AuthException
+from api.model.FactDatasourceQueryParameter import FactDatasourceQueryParameter
 from client import check_instance_avaliable, do_service
 from config.annotation import Value
 from factdatasource.FactDatasourceContext import FactDatasourceContext
@@ -21,6 +22,7 @@ from service.FactDatasourceService import FactDatasourceService
 
 log = logging.getLogger('Ficus')
 
+
 class FactDatasourceProxy(object):
 
     @abstractmethod
@@ -80,6 +82,16 @@ class FactDatasourceProxy(object):
         :return: Page
         """
 
+    @abstractmethod
+    def query_data(self, fd_code: str, query: str, parameters: dict):
+        """
+        使用查询语句查询数据
+        :param fd_code:
+        :param query: 查询语句
+        :param parameters: 查询参数
+        :return: Page
+        """
+
     @abstractmethod
     def inserts(self, fd_code: str, result_list: list) -> list:
         """
@@ -234,6 +246,9 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_field_permission(fd_context, result, False)
         return result
 
+    def query_data(self, fd_code: str, query: str, parameters: dict):
+        self.query(fd_code, query, parameters)
+
     def inserts(self, fd_code: str, result_list: list) -> list:
         """
         批量保存数据,要求list里面的字段和数据库里面的字段一一对应
@@ -506,6 +521,35 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
+    def query_data(self, fd_code: str, query: str, parameters: dict):
+        """
+        对数据集进行查询
+        :param fd_code: fd的唯一code
+        :param query: 查询语句
+        :param parameters: 查询可能涉及的参数 K/V形式
+        :return:
+        """
+        check_instance_avaliable()
+        query_parameter = FactDatasourceQueryParameter(query, parameters)
+        try:
+            r = do_service(f"/remote/fd-service/{fd_code}/queryData", method="post", data=dict(query_parameter))
+
+            if r is not None:
+                if isinstance(r, list):
+                    return [Munch(x) for x in r]
+                else:
+                    return Munch(r)
+            else:
+                return None
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 500:
+                # 说明服务器端报错了
+                raise ServiceInnerException(e.response._content.decode('utf-8'))
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
+                # 说明是认证相关的错误
+                raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
+            raise e
+
     def inserts(self, fd_code: str, result_list: list) -> list:
         """
         增加数据
