@@ -2,6 +2,8 @@
 # -*- encoding: utf-8 -*-
 # Author: lvbiao
 # Created on 2019/1/22
+from urllib.parse import unquote
+
 import pika
 from pika import BlockingConnection
 
@@ -127,7 +129,7 @@ class AmqpDatasource(BaseDatasource):
             credentials_list = self.credentials.split(':')
             username = credentials_list[0]
             password = credentials_list[1] if len(credentials_list) > 1 else ''
-            con_param['credentials'] = pika.PlainCredentials(username, password)
+            con_param['credentials'] = pika.PlainCredentials(unquote(username), unquote(password))
 
         block_con_param = pika.ConnectionParameters(**con_param)
         self.client = pika.BlockingConnection(block_con_param)
