@@ -3,6 +3,7 @@
 # Author: lvbiao
 # Created on 2019/1/22
 import threading
+from urllib.parse import unquote
 
 from sqlalchemy import create_engine
 from sqlalchemy.orm import Session, sessionmaker
@@ -232,7 +233,7 @@ class JdbcDatasource(BaseDatasource):
 
             path = '/' + str(database)
 
-            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port,
+            result_url = Url(scheme=sqlalchemy_scheme.value, auth=unquote(self._credentials), host=r.host, port=r.port,
                              path=path, query=query, fragment=r.fragment)
         elif jdbc_type == JdbcTypeEnum.ORACLE:
             # JDBC的常用形式是
@@ -287,7 +288,7 @@ class JdbcDatasource(BaseDatasource):
             else:
                 dsn = cx_Oracle.makedsn(host, port, sid=sid)
 
-            credentials = str(self._credentials) + '@' if self._credentials else ''
+            credentials = unquote(str(self._credentials)) + '@' if self._credentials else ''
             return f'{sqlalchemy_scheme.value}://{credentials}{dsn}'
         else:
             # 默认可以使用的比较通用的构造方式
@@ -302,7 +303,7 @@ class JdbcDatasource(BaseDatasource):
                 # 需要去掉 useSSL=true/false
                 query = "&".join(list(filter(lambda x: x.split("=")[0] not in ["useSSL", "_type_"], query.split("&"))))
 
-            result_url = Url(scheme=sqlalchemy_scheme.value, auth=self._credentials, host=r.host, port=r.port,
+            result_url = Url(scheme=sqlalchemy_scheme.value, auth=unquote(self._credentials), host=r.host, port=r.port,
                              path=r.path, query=query, fragment=r.fragment)
         return result_url.url
 
