@@ -2,7 +2,7 @@
 # -*- encoding: utf-8 -*-
 # Author: lvbiao
 # Created on 2019/1/22
-from urllib.parse import quote_plus
+from urllib.parse import quote_plus, unquote
 
 from pymongo import MongoClient
 from pymongo.database import Database
@@ -154,8 +154,8 @@ class MongoDatasource(BaseDatasource):
             user_db = "admin"
 
         if con_credential and ':' in con_credential:
-            uri_credential = quote_plus(con_credential[0:con_credential.find(':')]) + ':' \
-                             + quote_plus(con_credential[con_credential.find(':') + 1:]) + '@'
+            uri_credential = quote_plus(unquote(con_credential[0:con_credential.find(':')])) + ':' \
+                             + quote_plus(unquote(con_credential[con_credential.find(':') + 1:])) + '@'
         else:
             uri_credential = ''
 
