@@ -240,7 +240,7 @@ class SobeyHiveFactDatasourceContext(AbstractFactDatasourceContext):
         if 'entityData' not in entity:
             raise FDExecuteException(f'未设置entityData值，无法创建业务对象。{entity}')
 
-        type_name = self.fd().target
+        type_name = self.fd().get_target_with_schema()
         entity_data: dict = entity.get('entityData')
 
         # 1. 创建数据对象
